##  Introduction
Users with admin rights can create custom transformation templates from scratch and also customize the Rollout Application transformation template, and save it as new. These newly created templates will then be available for selection in initiative fact sheets while creating transformations.
Creating custom transformation templates offers you the flexibility to model more complex transformations involving your custom fields and custom fact sheets.
It allows you to:
  * Embed any custom impacts to the template itself instead of adding them every time a transformation template is used in the initiative fact sheet.
  * Change the template's name, category, and description and add fields, relationships, and impacts. For instance, add and set the lifecycle status field.
  * Remove or include specific fact sheet types based on their relevance to your rollout process. For example, adding process fact sheet type to the template in case the rollout of the application impacts processes.
  * Predefine the scope of fact sheets available for template users when they are adding fact sheets to a template field.
  * Re-label the fields of the template to make it descriptive, so that the template speaks the language of regular users in your organization.


![Configuring Transformation Template in Admin Settings](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b05207a441014b315f757e2367fbf_LowRes.png)
Configuring a Transformation Template in Admin Settings
Customization allows you to tailor the template to suit your specific needs and streamline your rollout process effectively in the following ways:
  * Addresses your transformation complexities that the default Rollout Application template doesn't cover.
  * Flexibility to decide the scope of the transformation by selecting the fact sheets that are relevant, either default or custom fact sheet types.
  * It enables regular users to work with the template effortlessly, as incorporating custom impacts can be challenging for users unfamiliar with the meta model or transformation expectations.
  * It ensures users can understand and fill templates easily, as the labels, descriptions, and language can match the organization's style.
